@@ -7,7 +7,7 @@
  * @date   2006-09-15
  * @brief  Common metadata image information manipulation methods
  *
- * @author Copyright (C) 2006-2012 by Gilles Caulier
+ * @author Copyright (C) 2006-2014 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2006-2012 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
@@ -45,9 +45,7 @@ bool KExiv2::setImageProgramId(const QString& program, const QString& version) c
 
         // Set program info into Exif.Image.ProcessingSoftware tag (only available with Exiv2 >= 0.14.0).
 
-#if (EXIV2_TEST_VERSION(0,14,0))
         d->exifMetadata()["Exif.Image.ProcessingSoftware"] = std::string(software.toAscii().constData());
-#endif
 
         // See B.K.O #142564: Check if Exif.Image.Software already exist. If yes, do not touch this tag.
 
@@ -88,6 +86,10 @@ bool KExiv2::setImageProgramId(const QString& program, const QString& version) c
     {
         d->printExiv2ExceptionError("Cannot set Program identity into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -177,6 +179,10 @@ QSize KExiv2::getImageDimensions() const
     {
         d->printExiv2ExceptionError("Cannot parse image dimensions tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QSize();
 }
@@ -213,6 +219,10 @@ bool KExiv2::setImageDimensions(const QSize& size, bool setProgramName) const
     {
         d->printExiv2ExceptionError("Cannot set image dimensions using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -226,6 +236,24 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
         long orientation;
         ImageOrientation imageOrient = ORIENTATION_NORMAL;
 
+        // -- Standard Xmp tag --------------------------------
+
+#ifdef _XMP_SUPPORT_
+
+        bool ok = false;
+        QString str = getXmpTagString("Xmp.tiff.Orientation");
+        if (!str.isEmpty())
+        {
+            orientation = str.toLong(&ok);
+            if (ok)
+            {
+                kDebug() << "Orientation => Xmp.tiff.Orientation => " << (int)orientation;
+                return (ImageOrientation)orientation;
+            }
+        }
+
+#endif // _XMP_SUPPORT_
+
         // Because some camera set a wrong standard exif orientation tag,
         // We need to check makernote tags in first!
 
@@ -281,29 +309,15 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
             return (ImageOrientation)orientation;
         }
 
-        // -- Standard Xmp tag --------------------------------
-
-#ifdef _XMP_SUPPORT_
-
-        bool ok = false;
-        QString str = getXmpTagString("Xmp.tiff.Orientation");
-        if (!str.isEmpty())
-        {
-            orientation = str.toLong(&ok);
-            if (ok)
-            {
-                kDebug() << "Orientation => Xmp.tiff.Orientation => " << (int)orientation;
-                return (ImageOrientation)orientation;
-            }
-        }
-
-#endif // _XMP_SUPPORT_
-
     }
     catch( Exiv2::Error& e )
     {
         d->printExiv2ExceptionError("Cannot parse Exif Orientation tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return ORIENTATION_UNSPECIFIED;
 }
@@ -374,6 +388,10 @@ bool KExiv2::setImageOrientation(ImageOrientation orientation, bool setProgramNa
     {
         d->printExiv2ExceptionError("Cannot set Exif Orientation tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -480,6 +498,10 @@ bool KExiv2::setImageColorWorkSpace(ImageColorWorkSpace workspace, bool setProgr
     {
         d->printExiv2ExceptionError("Cannot set Exif color workspace tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -496,9 +518,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::ExifKey key("Exif.Photo.DateTimeOriginal");
                 Exiv2::ExifData::iterator it = exifData.findKey(key);
+
                 if (it != exifData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Exif.Photo.DateTimeOriginal => " << dateTime;
@@ -509,9 +533,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::ExifKey key("Exif.Photo.DateTimeDigitized");
                 Exiv2::ExifData::iterator it = exifData.findKey(key);
+
                 if (it != exifData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Exif.Photo.DateTimeDigitized => " << dateTime;
@@ -522,9 +548,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::ExifKey key("Exif.Image.DateTime");
                 Exiv2::ExifData::iterator it = exifData.findKey(key);
+
                 if (it != exifData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Exif.Image.DateTime => " << dateTime;
@@ -544,9 +572,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.exif.DateTimeOriginal");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.exif.DateTimeOriginal => " << dateTime;
@@ -557,9 +587,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.exif.DateTimeDigitized");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.exif.DateTimeDigitized => " << dateTime;
@@ -570,9 +602,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.photoshop.DateCreated");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.photoshop.DateCreated => " << dateTime;
@@ -583,9 +617,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.xmp.CreateDate");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.xmp.CreateDate => " << dateTime;
@@ -596,9 +632,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.tiff.DateTime");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.tiff.DateTime => " << dateTime;
@@ -609,9 +647,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.xmp.ModifyDate");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.xmp.ModifyDate => " << dateTime;
@@ -622,9 +662,11 @@ QDateTime KExiv2::getImageDateTime() const
             {
                 Exiv2::XmpKey key("Xmp.xmp.MetadataDate");
                 Exiv2::XmpData::iterator it = xmpData.findKey(key);
+
                 if (it != xmpData.end())
                 {
                     QDateTime dateTime = QDateTime::fromString(it->toString().c_str(), Qt::ISODate);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Xmp.xmp.MetadataDate => " << dateTime;
@@ -646,17 +688,20 @@ QDateTime KExiv2::getImageDateTime() const
 
             Exiv2::IptcKey keyDateCreated("Iptc.Application2.DateCreated");
             Exiv2::IptcData::iterator it = iptcData.findKey(keyDateCreated);
+
             if (it != iptcData.end())
             {
                 QString IptcDateCreated(it->toString().c_str());
                 Exiv2::IptcKey keyTimeCreated("Iptc.Application2.TimeCreated");
                 Exiv2::IptcData::iterator it2 = iptcData.findKey(keyTimeCreated);
+
                 if (it2 != iptcData.end())
                 {
                     QString IptcTimeCreated(it2->toString().c_str());
                     QDate date = QDate::fromString(IptcDateCreated, Qt::ISODate);
                     QTime time = QTime::fromString(IptcTimeCreated, Qt::ISODate);
                     QDateTime dateTime = QDateTime(date, time);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Iptc.Application2.DateCreated => " << dateTime;
@@ -669,17 +714,20 @@ QDateTime KExiv2::getImageDateTime() const
 
             Exiv2::IptcKey keyDigitizationDate("Iptc.Application2.DigitizationDate");
             Exiv2::IptcData::iterator it3 = iptcData.findKey(keyDigitizationDate);
+
             if (it3 != iptcData.end())
             {
                 QString IptcDateDigitization(it3->toString().c_str());
                 Exiv2::IptcKey keyDigitizationTime("Iptc.Application2.DigitizationTime");
                 Exiv2::IptcData::iterator it4 = iptcData.findKey(keyDigitizationTime);
+
                 if (it4 != iptcData.end())
                 {
                     QString IptcTimeDigitization(it4->toString().c_str());
                     QDate date = QDate::fromString(IptcDateDigitization, Qt::ISODate);
                     QTime time = QTime::fromString(IptcTimeDigitization, Qt::ISODate);
                     QDateTime dateTime = QDateTime(date, time);
+
                     if (dateTime.isValid())
                     {
                         kDebug() << "DateTime => Iptc.Application2.DigitizationDate => " << dateTime;
@@ -693,6 +741,10 @@ QDateTime KExiv2::getImageDateTime() const
     {
         d->printExiv2ExceptionError("Cannot parse Exif date & time tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return QDateTime();
 }
@@ -761,6 +813,10 @@ bool KExiv2::setImageDateTime(const QDateTime& dateTime, bool setDateTimeDigitiz
     {
         d->printExiv2ExceptionError("Cannot set Date & Time into image using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -829,6 +885,10 @@ QDateTime KExiv2::getDigitizationDateTime(bool fallbackToCreationTime) const
     {
         d->printExiv2ExceptionError("Cannot parse Exif digitization date & time tag using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     if (fallbackToCreationTime)
         return getImageDateTime();
@@ -850,6 +910,10 @@ bool KExiv2::getImagePreview(QImage& preview) const
     {
         d->printExiv2ExceptionError("Cannot get image preview using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -892,6 +956,10 @@ bool KExiv2::setImagePreview(const QImage& preview, bool setProgramName) const
     {
         d->printExiv2ExceptionError("Cannot get image preview using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
